multiformats.multihash.err
==========================

.. automodule:: multiformats.multihash.err

MultihashKeyError
-----------------

.. autoclass:: multiformats.multihash.err.MultihashKeyError
    :members:

MultihashValueError
-------------------

.. autoclass:: multiformats.multihash.err.MultihashValueError
    :members:
